@@ -1,14 +1,17 @@
-/* global forms */
+import getExplicitRole from '../aria/get-explicit-role';
+
 const rangeRoles = ['progressbar', 'scrollbar', 'slider', 'spinbutton'];
 
 /**
  * Determines if an element is an aria range element
  * @method isAriaRange
  * @memberof axe.commons.forms
- * @param {Element} node Node to determine if aria range
+ * @param {VirtualNode|Element} node Node to determine if aria range
  * @returns {Bool}
  */
-forms.isAriaRange = function(node) {
-	const role = axe.commons.aria.getRole(node, { noImplicit: true });
+function isAriaRange(node) {
+	const role = getExplicitRole(node);
 	return rangeRoles.includes(role);
-};
+}
+
+export default isAriaRange;
